@@ -1,12 +1,12 @@
 #
-# $Id: UTF7.pm,v 2.0 2004/05/16 20:55:17 dankogai Exp $
+# $Id: UTF7.pm,v 2.1 2004/05/25 16:27:14 dankogai Exp $
 #
 package Encode::Unicode::UTF7;
 use strict;
 no warnings 'redefine';
 use base qw(Encode::Encoding);
 __PACKAGE__->Define('UTF-7');
-our $VERSION = do { my @r = (q$Revision: 2.0 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 2.1 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 use MIME::Base64;
 use Encode;
 
@@ -38,7 +38,8 @@ sub encode($$;$){
 	    if ($1 eq "+"){
 		$bytes .= "+-";
 	    }else{
-		my $base64 = encode_base64($e_utf16->encode($1), '');
+		my $s = $1;
+		my $base64 = encode_base64($e_utf16->encode($s), '');
 		$base64 =~ s/=+$//;
 		$bytes .= "+$base64-";
 	    }
@@ -50,10 +51,11 @@ sub encode($$;$){
     return $bytes;
 }
 	   
-sub decode{
+sub decode($$;$){
     my ($obj, $bytes, $chk) = @_;
     my $len = length($bytes);
     my $str = "";
+    no warnings 'uninitialized';
     while (pos($bytes) < $len) {
 	if    ($bytes =~ /\G([^+]+)/ogc) {
 	    $str .= $1;
